@@ -13,15 +13,15 @@ www.xmailserver.com
 
 =head1 VERISON
 
-version 1.0 of XMail::Ctrl
+version 1.2 of XMail::Ctrl
 
-released 07/06/2001
+released 02/03/2002
 
 =head1 SYNOPSIS
 
 	use XMail::Ctrl;
 	my $XMail_admin      = "aaron.johnson";
-	my $XMail_pass       = "stickman";
+	my $XMail_pass       = "mypass";
 	my $XMail_port       = "6017";
 	my $XMail_host       = "aopen.hank.net";
 	my $test_domain      = "aopen.hank.net";
@@ -43,6 +43,17 @@ released 07/06/2001
 			}
 			);
 	
+	# setting the mailproc.tab
+
+    my $proc = $xmail->usersetmproc(
+            {
+                username       => "$test_user",
+			    domain         => "$test_domain",
+			    output_to_file => "command for mailproc.tab",
+
+			}
+			 );
+	
 	$xmail->quit;
 
 =head1 DESCRIPTION
@@ -96,14 +107,21 @@ To send uservarsset add a vars anonymous hash, such as:
 
 The ".|rm" command can used as described in the XMail docs.
 
+The lists are returned in a single string.  If I get enough
+requests I will modify this behavior.  I have thought about
+either an array or arrays or hash of arrays.
+
 =head1 BUGS
 
-There must be some
+Possible problems dealing with wild card requests.  I have
+not tested this fully.  Please send information on what you
+are attempting if you feel the module is not providing the
+correct function.
 
 =head1 AUTHOR
 
 Aaron Johnson
-aaron@provillage.com
+solution@gina.net
 
 =head1 THANKS
 
@@ -117,9 +135,18 @@ AUTOLOAD was revealed to me.
 Thanks to my Dad for buying that TRS-80 in 1981 and getting
 me addicted to computers.
 
-Thanks to my wife for leaving me alone while I write me code
+Thanks to my wife for leaving me alone while I write my code
 :^)
 
+Thanks to Oscar Sosa for spotting the lack of support for
+editing the 'tab' files
+
+=head1 CHANGES
+
+1.2 - Added support for the usersetmproc command
+
+1.0 - Initial release
+
 =head1 COPYRIGHT
 
 Copyright (c) 2000, Aaron Johnson.  All rights Reserved.
@@ -129,7 +156,7 @@ and/or modified under the same terms as Perl itself.
 =cut
 
 # Perl interface to crtl for XMail
-# Written by Aaron Johnson aaron@provillage.com
+# Written by Aaron Johnson solution@gina.net
 
 # Once you create a new xmail connection don't
 # let it sit around too long or it will time out!
@@ -178,6 +205,7 @@ sub new {
 		_port     => $args{port},
 		_host     => $args{host},
 		_io       => $s,
+
 	};
 
 	bless ($outmail , $class);
@@ -204,7 +232,7 @@ sub xcommand {
 	extrn-username
 	extrn-password
 	authtype
-	realitive-file-path
+	relative-file-path
 	vars);
 	
 	my $command = $args->{command};
@@ -226,18 +254,25 @@ sub xcommand {
 	$command .= "\r\n";
 
 	$s->print($command);
-
-	my ($test,$buf,$list);
+    
+	my ($test,$buf,$list,$proc);
 	while (1) {
 		sysread $s, $buf, 1;
 		# stop reading if we have a newline unless we expect
 		# a list
-		if ($buf =~ /\n$/ && !$list) {
+		if ($buf =~ /\n$/ && !$list && !$proc) {
 			last;
 		}
+		
 		$test .= $buf;
 		# lists have a response of +00100 from the server
 		if ($test =~ /\+00100/) { $list = 1 }
+		if ($test =~ /\+00101/) { $proc = 1 }
+		if ($buf =~ /\n$/ && $proc) {
+		    $s->print($args->{output_to_file} . "\n.\r\n");
+		    $proc = '';
+		    last;
+		}
 		
 		# stop reading if the string ends with
 		# . return newline
